@@ -18,11 +18,11 @@ Mojo::Pg::Che - mix of parent Mojo::Pg and DBI.pm
 
 =head1 VERSION
 
-Version 0.052
+Version 0.06
 
 =cut
 
-our $VERSION = '0.052';
+our $VERSION = '0.06';
 
 
 =head1 SYNOPSIS
@@ -304,20 +304,25 @@ sub _dequeue {
   #~ while (my $dbh = shift @{$self->{queue} || []}) { return $dbh if $dbh->ping }
   
   my $queue = $self->{queue} ||= [];
-  
   for my $i (0..$#$queue) {
     
     my $dbh = $queue->[$i];
     
-    delete $queue->[$i]
-      and next
+    #~ warn "pg_async_status: ", $dbh->{pg_async_status} and
+    next
+      if $dbh->{pg_async_status} && $dbh->{pg_async_status} > 0;
+    
+    splice(@$queue, $i, 1);    #~ delete $queue->[$i]
+    
+    #~ warn "queue-- $dbh", scalar @$queue and 
+    return $dbh
       if $dbh->ping;
     
-    return (splice(@$queue, $i, 1))[0]
-      unless $dbh->{pg_async_status} > 0;
   }
   
   my $dbh = DBI->connect(map { $self->$_ } qw(dsn username password options));
+  #~ say STDERR "НОвое [$dbh] соединение";
+  
 
   #~ if (my $path = $self->search_path) {
     #~ my $search_path = join ', ', map { $dbh->quote_identifier($_) } @$path;
@@ -331,6 +336,14 @@ sub _dequeue {
   return $dbh;
 }
 
+sub _enqueue {
+  my ($self, $dbh) = @_;
+  my $queue = $self->{queue} ||= [];
+  #~ warn "queue++ $dbh:", scalar @$queue and
+  push @$queue, $dbh
+    if $dbh->{Active} && @$queue < $self->max_connections;
+  #~ shift @$queue while @$queue > $self->max_connections;
+}
 
 1;
 
